.TH ssync 1 "March 22, 2002"
.SH NAME
ssync \- minimalistic filesystem sync tool
.SH SYNOPSIS
.B ssync
.RI [ options ]
.PP
.B ssyncd
.RI [ options ]
.SH DESCRIPTION
Ssync is a minimalistic filesystem synchronization utility. Its primary
goals are reliability, correctness, and speed in syncing extremely large
filesystems over fast, local network connections. Ssync does not implement
encryption, compression, differencing algorithms, or remote synchronization
over a pipe such as rsh / ssh since those features are already well covered
by other utilities such as rsync.
.PP
Ssync works well on large filesystems and can handle filesystem objects
with unusual and non-ASCII characters in their names while correctly preserving
all symbolic and hard links and all mode bits. It can be run at increased or
decreased niceness and can provide several levels of logging output. Several
options allow complete control of synchronization behaviors such as selectively
disabling updating of data, ownership, and modes, as well as updating only newer
objects or just performing 'test runs'.
.PP
The basic behavior of both interactive and daemon versions of the program is to
read a list of source and destination paths from a specified work file and take
whatever actions are necessary to make the destinations identical to the sources.
Each line of the work file takes the form:
.PP
.B <source path> | <destination path>
.PP
Any text following a # character to end of line in the work file is considered
a comment and ignored.
.SH OPTIONS
All options may be set on the command line in either short or long form as well
as in a configuration file. For the interactive version (\fBssync\fR), the default
configuration file is \fB.ssyncrc\fR in the current directory. For the daemon
(\fBssyncd\fR), \fB/etc/ssyncd.conf\fR is the default. Settings in the configuration
file have the same name as the long option and take a form such as:
.PP
.B work-file:   /etc/ssyncd.work
.PP
Any text following a # character to end of line in the configuration file is
considered a comment and ignored. Example configuration and work files, as well
as some more extensive development rationale may be found in the file README.HTML.
If you installed a binary package, this file as well as some examples should be
located in your distribution's doc directory for this package. If you built from
a source tarball, then it should have included the documentation and example files.
.TP
\fB\-h \-\-help\fR
display usage message and version
.TP
\fB\-c\fR \fIPATH\fR \fB\-\-conf-path=\fR\fIPATH\fR
read alternative config file from the default
.TP
\fB\-i\fR \fINUM\fR \fB\-\-interval=\fR\fINUM\fR
number of seconds to sleep between completing one run and starting the next
.TP
\fB\-w\fR \fIPATH\fR \fB\-\-work-file=\fR\fIPATH\fR
path for file containing work list (see also \fBsrc-path\fR and \fBdst-path\fR)
.TP
\fB\-f\fR \fIPATH\fR \fB\-\-src-path=\fR\fIPATH\fR
alternative way to specify a single source path
.TP
\fB\-t\fR \fIPATH\fR \fB\-\-dst-path=\fR\fIPATH\fR
alternative way to specify a single destination path
.TP
\fB\-n\fR \fI(-20 - +20)\fR \fB\-\-priority=\fR\fI(-20 - +20)\fR
scheduling priority or 'niceness', lower numbers are more rude, see \fBrenice\fR(8), for more
details
.TP
\fB\-F \-\-no-detach\fR
do not daemonize (use with \fBlog-mode: stderr\fR)
.TP
\fB\-D \-\-no-sync-data\fR
do not sync data (content) of files
.TP
\fB\-T \-\-no-sync-time\fR
do not sync atime / mtime
.TP
\fB\-M \-\-no-sync-meta\fR
do not sync meta-data (uid / gid / mode)
.TP
\fB\-U \-\-update-only\fR
only sync things if source mtime is > destination mtime
.TP
\fB\-X \-\-test\fR
run sync procedure and collect statistics without actually modifying anything
.TP
\fB\-p\fR \fIPATH\fR \fB\-\-pid-path=\fR\fIPATH\fR
path for pid file
.TP
\fB\-m\fR \fI(file|syslog|stderr)\fR \fB\-\-log-mode=\fR\fI(file|syslog|stderr)\fR
logging mode
.TP
\fB\-l\fR \fIPATH\fR \fB\-\-log-path=\fR\fIPATH\fR
path for log file if using file based logging
.TP
\fB\-s\fR \fISTRING\fR \fB\-\-log-ident=\fR\fISTRING\fR
identification string if using syslog based logging
.TP
\fB\-v\fR \fI(0 - 5)\fR \fB\-\-log-level=\fR\fI(0 - 5)\fR
logging verbosity, 2 is default, 3 is errors only, 0 lists all updates and deletions
.SH FILES
.TP
\fI$PWD/.ssync\fR
default configuration file for \fBssync\fR
.TP
\fI/etc/ssyncd.conf\fR
default configuration file for \fBssyncd\fR
.TP
\fI/etc/ssyncd.work\fR
default work file for \fBssyncd\fR
.TP
\fI/var/log/ssyncd.log\fR
default log file for \fBssyncd\fR
.TP
\fI/var/run/ssyncd.pid\fR
default pid file for \fBssyncd\fR
.SH BUGS
Due to the simple-mindedness of the configuration file parser, paths containing whitespaces
and unusual characters in the work file will not be parsed properly. This limitation does not
apply to anything underneath the specified paths, just the starting points as listed in the
work file.
.SH AUTHOR
This manual page was written by Michael W. Shaffer <mwshaffer@angrypot.com>,
